# coding=utf-8
# Copyright (C) 2019+ Alice, Vigo, Spain

"""Public API of ALiCE Petisco Framework"""


# Classes
from petisco.use_case import UseCase
from petisco.use_case import use_case_logger
from petisco.controller.controller_decorator import controller
from petisco.controller.correlation_id import CorrelationId
from petisco.controller.errors.http_error import HttpError

classes = ["UseCase", "use_case_logger", "controller", "CorrelationId", "HttpError"]

__all__ = classes



import os

from setuptools import setup

CURRENT_DIR = os.path.abspath(os.path.dirname(__file__))
PACKAGE_NAME = "petisco"
VERSION = "0.0.3"

# The text of the README file
with open(os.path.join(CURRENT_DIR, "README.md")) as fid:
    README = fid.read()

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description="Petisco is a framework for helping Python developers to build clean Applications",
    long_description=README,
    long_description_content_type="text/markdown",
    keywords=["DDD", "Use Case", "Clean Architecture", "REST", "Applications"],
    url="https://github.com/alice-biometrics/petisco",
    author="ALiCE Biometrics",
    author_email="support@alicebiometrics.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
    ],
    packages=["petisco", "petisco/use_case", "petisco/logger", "petisco/controller", "petisco/controller/errors", "petisco/controller/jwt"],
    zip_safe=False,
)
